==> oceanbolt.sdk-0.0.8.tar.gz: oceanbolt.sdk-0.0.8/oceanbolt/com/entities/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from oceanbolt.com.entities_v3.services.entity_service.async_client import EntityServiceAsyncClient
from oceanbolt.com.entities_v3.services.entity_service.client import EntityServiceClient
from oceanbolt.com.entities_v3.types.service import Commodity
from oceanbolt.com.entities_v3.types.service import Country
from oceanbolt.com.entities_v3.types.service import EmptyParams
from oceanbolt.com.entities_v3.types.service import ListCommoditiesResponse
from oceanbolt.com.entities_v3.types.service import ListCountriesRequest
from oceanbolt.com.entities_v3.types.service import ListCountriesResponse
from oceanbolt.com.entities_v3.types.service import ListPortsResponse
from oceanbolt.com.entities_v3.types.service import ListRegionsRequest
from oceanbolt.com.entities_v3.types.service import ListRegionsResponse
from oceanbolt.com.entities_v3.types.service import ListRegionsWithPolygonResponse
from oceanbolt.com.entities_v3.types.service import ListSegmentsResponse
from oceanbolt.com.entities_v3.types.service import ListTonnageZonesResponse
from oceanbolt.com.entities_v3.types.service import ListTonnageZonesWithPolygonsResponse
from oceanbolt.com.entities_v3.types.service import Port
from oceanbolt.com.entities_v3.types.service import Region
from oceanbolt.com.entities_v3.types.service import RegionWithPolygon
from oceanbolt.com.entities_v3.types.service import Segment
from oceanbolt.com.entities_v3.types.service import Zone
from oceanbolt.com.entities_v3.types.service import ZoneWithPolygon

__all__ = (
    'Commodity',
    'Country',
    'EmptyParams',
    'EntityServiceAsyncClient',
    'EntityServiceClient',
    'ListCommoditiesResponse',
    'ListCountriesRequest',
    'ListCountriesResponse',
    'ListPortsResponse',
    'ListRegionsRequest',
    'ListRegionsResponse',
    'ListRegionsWithPolygonResponse',
    'ListSegmentsResponse',
    'ListTonnageZonesResponse',
    'ListTonnageZonesWithPolygonsResponse',
    'Port',
    'Region',
    'RegionWithPolygon',
    'Segment',
    'Zone',
    'ZoneWithPolygon',
)

==> oceanbolt.sdk-0.1.9.tar.gz: oceanbolt.sdk-0.1.9/oceanbolt/com/entities/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from oceanbolt.com.entities_v3.services.entity_service.async_client import EntityServiceAsyncClient
from oceanbolt.com.entities_v3.services.entity_service.client import EntityServiceClient
from oceanbolt.com.entities_v3.types.service import Commodity
from oceanbolt.com.entities_v3.types.service import Country
from oceanbolt.com.entities_v3.types.service import EmptyParams
from oceanbolt.com.entities_v3.types.service import ListCommoditiesResponse
from oceanbolt.com.entities_v3.types.service import ListCountriesRequest
from oceanbolt.com.entities_v3.types.service import ListCountriesResponse
from oceanbolt.com.entities_v3.types.service import ListPortsResponse
from oceanbolt.com.entities_v3.types.service import ListRegionsRequest
from oceanbolt.com.entities_v3.types.service import ListRegionsResponse
from oceanbolt.com.entities_v3.types.service import ListRegionsWithPolygonResponse
from oceanbolt.com.entities_v3.types.service import ListSegmentsResponse
from oceanbolt.com.entities_v3.types.service import ListTonnageZonesResponse
from oceanbolt.com.entities_v3.types.service import ListTonnageZonesWithPolygonsResponse
from oceanbolt.com.entities_v3.types.service import Polygon
from oceanbolt.com.entities_v3.types.service import Port
from oceanbolt.com.entities_v3.types.service import Region
from oceanbolt.com.entities_v3.types.service import RegionWithPolygon
from oceanbolt.com.entities_v3.types.service import SearchPolygonsResponse
from oceanbolt.com.entities_v3.types.service import SearchRequest
from oceanbolt.com.entities_v3.types.service import SearchVesselsResponse
from oceanbolt.com.entities_v3.types.service import Segment
from oceanbolt.com.entities_v3.types.service import Vessel
from oceanbolt.com.entities_v3.types.service import Zone
from oceanbolt.com.entities_v3.types.service import ZoneWithPolygon

__all__ = (
    'Commodity',
    'Country',
    'EmptyParams',
    'EntityServiceAsyncClient',
    'EntityServiceClient',
    'ListCommoditiesResponse',
    'ListCountriesRequest',
    'ListCountriesResponse',
    'ListPortsResponse',
    'ListRegionsRequest',
    'ListRegionsResponse',
    'ListRegionsWithPolygonResponse',
    'ListSegmentsResponse',
    'ListTonnageZonesResponse',
    'ListTonnageZonesWithPolygonsResponse',
    'Polygon',
    'Port',
    'Region',
    'RegionWithPolygon',
    'SearchPolygonsResponse',
    'SearchRequest',
    'SearchVesselsResponse',
    'Segment',
    'Vessel',
    'Zone',
    'ZoneWithPolygon',
)
